## Simulation after polarisation data of Data of Williams(1965)
## Source: Keith R. Williams \ M.R. Andrew \ F. Jones,
## Hydrocarbon Fuel Cell Technology,
## Symposium 150th Meeting of the American Chemical Society in Atlantic City \ pp. 143-149 (1965),

## ------------------------------------------------------------
reset
## change directory
cd 'C:\home\stefan_pofahl\Dokumente\P\promotion\tex\pictures\Gnu_plot-Sources\Chap_Model\pol_graph'

# Input file contains comma-separated values fields
set datafile separator ","

## user defined variables
Filename = "normed_pol_over_j.tex"

## choosing "set style increment userstyles" allows you to step through the user-defined
## line styles rather than through the default linetypes.
set style increment userstyles

## set macros: If command line macro substitution is enabled, then tokens in the command line
## of the form @<stringvariablename> will be replaced by the text string contained in <stringvariablename>.
set macros
## Plot Styles, lines, points, linespoints, lt= linetype, lw= linewidth, pt= pointtype, ps= pointsize
## list colour names: show palette colornames
# style_EO_PTS = 'points lt 1 lc rgb "grey20" pt 6 ps 2'
style_anode = 'lines lt 1 lw 2.5 lc rgb "dark-blue" '
style_cathode = 'lines lt 2 lw 4.5 lc rgb "red" '
style_crossover = 'lines lt 8 lw 3.5 lc rgb "blue" '
style_oxred = 'lines lt 7 lw 3.5 lc rgb "dark-red" '
style_JBV_crossover = 'lines lt 3 lw 2.5 lc rgb "blue" '
style_JBV_oxred = 'lines lt 4 lw 2.5 lc rgb "dark-red" '

## linestyles
set style line 10 lc rgb "dark-green" lt 1 lw 2

## Origin, Size, margins
set size ratio 0.7
set lmargin 3.5
set rmargin 3.5
# set tmargin 0.5

## axes, tics, scale, axes range
# set xrange [-1:1]
# set zeroaxis lt 0 lw 0.7
set ytics nomirror
set format y "{%.1f{}\\quad{}}"
set y2range [100:*]
set y2tics
set format y2 "{$\\quad10^{%L}$}"
set logscale y2

## Annotions, Title and so on
## Key Box / Legend
# set key center left Right
set key at graph 0.25,0.7 Right
set key spacing 4
# set size ratio 1,2
## pol x coord j_co max 0.632192691

## labels

## axis labels
set xlabel "{Normed current $I^{\\Pi}_{fc} = I^{\\Pi}_{\\mathsc{ca}} = I/I_{max}$}" font ", 10"
set ylabel "{Normed polarization $\\Upl^{\\Pi} = |\\Upl/\\Upl_{max}|$}" offset first 0.27,0  font ", 10"
set y2label "{|I/Catalyst surface|  |\\JSi| $~\\diagup{}~$ A/m\\tss{2}}" offset -12,0 font ", 10"

## plotsection ---------------------------------------------------------------------------------------------
set terminal epslatex standalone newstyle dashlength 2.0 linewidth 2.0 rounded blacktext
set terminal epslatex font "" 12
set output Filename
set terminal epslatex size 7.0,3.5

## \264 is center point, \\100 masced @-char
plot \
  "pol298k.csv" using ($7/931.019905):(($10 - $34)/0.778453273) title "{$\\Upl^{\\Pi}_{\\mathsc{co}}$~\\,\\,}" with @style_crossover, \
  "pol298k.csv" using ($7/931.019905):($12/-0.778453273) title "{$\\Upl^{\\Pi}_{\\mathsc{or}}$~\\,\\,}" with @style_oxred, \
  "pol298k.csv" using ($7/931.019905):($25) axes x1y2 title "{$\\JSi_{\\mathsc{co}}$~\\,\\,}" with @style_JBV_crossover, \
  "pol298k.csv" using ($7/931.019905):($24) axes x1y2 title "{$\\JSi_{\\mathsc{or}}$~\\,\\,}" with @style_JBV_oxred




## close output file
unset output

## call system
system(sprintf("%s %s %s %s", "gnuplot2ps.bat", Filename, "eps", ""))
# system(sprintf("%s %s %s %s", "gnuplot2ps.bat", Filename, "pdfx", ""))
# system(sprintf("%s %s %s %s", "gnuplot2ps.bat", Filename, "pdflatex", "dbg"))

## last commands
show margin
